@@ -23,6 +23,10 @@ if TYPE_CHECKING:
     from textual.app import ComposeResult
 
 
+class NonSelectableStatic(Static):
+    ALLOW_SELECT = False
+
+
 class NoSelection:
     """Used by the `Select` widget to flag the unselected state. See [`Select.BLANK`][textual.widgets.Select.BLANK]."""
 
@@ -46,6 +50,8 @@ class SelectOverlay(OptionList):
 
     BINDINGS = [("escape", "dismiss", "Dismiss menu")]
 
+    ALLOW_SELECT = False
+
     @dataclass
     class Dismiss(Message):
         """Inform ancestor the overlay should be dismissed."""
@@ -184,6 +190,7 @@ class SelectCurrent(Horizontal):
         width: 1fr;
         height: auto;
         padding: 0 2;
+        pointer: pointer;
 
         &.-textual-compact {
             border: none !important;
@@ -217,6 +224,8 @@ class SelectCurrent(Horizontal):
     }
     """
 
+    ALLOW_SELECT = False
+
     has_value: var[bool] = var(False)
     """True if there is a current value, or False if it is None."""
 
@@ -247,9 +256,9 @@ class SelectCurrent(Horizontal):
 
     def compose(self) -> ComposeResult:
         """Compose label and down arrow."""
-        yield Static(self.placeholder, id="label")
-        yield Static("▼", classes="arrow down-arrow")
-        yield Static("▲", classes="arrow up-arrow")
+        yield NonSelectableStatic(self.placeholder, id="label")
+        yield NonSelectableStatic("▼", classes="arrow down-arrow")
+        yield NonSelectableStatic("▲", classes="arrow up-arrow")
 
     def _watch_has_value(self, has_value: bool) -> None:
         """Toggle the class."""
@@ -286,6 +295,8 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
     | enter,down,space,up | Activate the overlay |
     """
 
+    ALLOW_SELECT = False
+
     DEFAULT_CSS = """
     Select {
         height: auto;
